Learn R Programming

fwtraits (version 1.0.0)

fw_cite: Get database citations

Description

Get database citations

Usage

fw_cite(cachefolder = "cache")

Value

string of the package citation

Arguments

cachefolder

string. The root path were the cached data will be saved on the user PC. If the path is not provided, the cached information will be saved in the current working directly.