Learn R Programming

fwtraits (version 1.0.0)

fw_geosites: Auto generation of species sites

Description

Auto generation of species sites

Usage

fw_geosites(x, dist = 1000)

Value

dataframe

Arguments

x

dataframe Geo spatial data with geometry column from sf package.

dist

integer The distance used to cluster points as sites. The default is 1000.

Examples

Run this code

if (FALSE) {
geospdata <- speciesdata |>
sf::st_as_sf(coords = c('decimalLongitude', 'decimalLatitude'),
            crs = sf::st_crs(4326))
 xx <- fw_geosites(geospdata)
}

Run the code above in your browser using DataLab