powered by
Auto generation of species sites
fw_geosites(x, dist = 1000)
dataframe
dataframe Geo spatial data with geometry column from sf package.
integer The distance used to cluster points as sites. The default is 1000.
integer
if (FALSE) { geospdata <- speciesdata |> sf::st_as_sf(coords = c('decimalLongitude', 'decimalLatitude'), crs = sf::st_crs(4326)) xx <- fw_geosites(geospdata) }
Run the code above in your browser using DataLab