fw_setapikey: Function and instructions creating the API_KEY variable in the User environment.
Description
Function and instructions creating the API_KEY variable in the User environment.
Usage
fw_setapikey(verbose = TRUE)
Value
string of instructions for saving or setting the API in the R session.
Arguments
- verbose
logical If logical, then the instruction message will show. Default TRUE.